.. Django Gum documentation master file, created by
   sphinx-quickstart on Fri Apr  8 20:52:01 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Gum!
======================

Django Gum provides an easy way to integrate Django with **Elasticsearch 1.7.X**.
It can be use for indexing models, handle mappings and make queries.

The design was made assuming the user has some knowledge about how Elasticsearch works, therefore, this
package **DOES NOT** give you API like Django ORM.

.. toctree::
   :maxdepth: 2

   tutorial
   settings
   commands

.. note::

    This package was initialy developed for `Onpublico <https://onpublico.com>`_
    project.
